// 
// このコードは、https://demo.mescius.jp/diodocs/pdf のサンプルの一部として提供されています。
// © MESCIUS inc. All rights reserved.
// 
using System;
using System.IO;
using System.Drawing;
using System.Linq;
using System.Collections.Generic;
using GrapeCity.Documents.Pdf;
using GrapeCity.Documents.Text;
using GrapeCity.Documents.Svg;
using GCTEXT = GrapeCity.Documents.Text;
using GCDRAW = GrapeCity.Documents.Drawing;
using DsPdfWeb.Demos.Common;

namespace DsPdfWeb.Demos
{
    // このサンプルでは、コンテンツがビューポート内でオフセットされた SVG 画像の
    // 実際のコンテンツを測定しレンダリングする方法を示しています。
    // ページの左側では、コンテンツがオフセットされた SVG を、
    // ビューポート内にてレイアウトされたとおりにレンダリングします。
    // ビューポートの周囲には灰色、SVG コンテンツの周囲には赤紫色のボーダーを描画します。
    // ページの右側では、特定の位置に画像のコンテンツだけを配置し、
    // その周りに紫色のボーダーを描画しています。
    //
    // このサンプルで使用している SVG アートは、https://freesvg.org/ のものです。
    public class RenderSvgContent
    {
        public int CreatePDF(Stream stream)
        {
            // SVG を読み込みます。
            var svgPath = Path.Combine("Resources", "SvgMisc", "Smiling-Girl-offset.svg");
            using var svg = GcSvgDocument.FromFile(svgPath);

            var doc = new GcPdfDocument();
            var page = doc.NewPage();
            page.Landscape = true;
            var g = page.Graphics;
            var margin = g.Resolution / 2;
            var pt0 = new PointF(margin, margin);

            // ビューポート内の SVG レイアウトで指定されたとおりに SVG コンテンツをレンダリングします。
            var rcViewport = new RectangleF(pt0, svg.GetIntrinsicSize(SvgLengthUnits.Points));
            // 'pt0'を基準として、コンテンツのサイズおよび位置を測定します。
            var rcContent0 = g.MeasureSvg(svg, pt0);
            // SVG およびビューポートとコンテンツのボーダーを描画します。
            g.DrawSvg(svg, pt0);
            g.DrawRectangle(rcViewport, Color.DarkGray);
            g.DrawRectangle(rcContent0, Color.Magenta);

            // ビットマップの左側にて、SVG コンテンツの左上隅をビットマップの
            // 特定の位置（横方向はページの中央、縦方向は上から1インチ）に合わせて
            // SVGコンテンツだけをレンダリングします。
            var pt1 = new PointF(page.Size.Width / 2, margin);
            // GcGraphics.MeasureSvg() の代替手段として GcSvgDocument.Measure() があります。
            // ここでは説明のために使用していますが、このメソッドは計算が重いので、
            // 実際のアプリケーションでは上記の GcGraphics.MeasureSvg() の結果を再利用することになるでしょう。
            var rcContent1 = svg.Measure(PointF.Empty, g.Resolution);
            g.DrawSvg(svg, new PointF(pt1.X - rcContent1.X, pt1.Y - rcContent1.Y));
            // ボーダーを追加します。
            g.DrawRectangle(new RectangleF(pt1, rcContent1.Size), Color.Purple);

            // PDF ドキュメントを保存します。
            doc.Save(stream);
            return doc.Pages.Count;
        }
    }
}
